@@ -20,7 +20,6 @@
 #include "kcmwacomtabletwidget.h"
 
 #include "ui_kcmwacomtabletwidget.h"
-#include "ui_saveprofile.h"
 #include "ui_errorwidget.h"
 
 #include "logging.h"
@@ -36,6 +35,8 @@
 #include "dbustabletinterface.h"
 #include "devicetype.h"
 
+#include <KMessageBox>
+
 //Qt includes
 #include <QDBusReply>
 #include <QPointer>
@@ -46,6 +47,7 @@
 #include <QDialogButtonBox>
 #include <QX11Info>
 #include <QMessageBox>
+#include <QScrollArea>
 
 using namespace Wacom;
 
@@ -68,6 +70,13 @@ class KCMWacomTabletWidgetPrivate {
 }; // CLASS
 }  // NAMESPACE
 
+void makeScrollableTab(QTabWidget *parent, QWidget &tab, const QString &title) {
+    auto scrollableTab = new QScrollArea(parent);
+    scrollableTab->setWidget(&tab);
+    scrollableTab->setWidgetResizable(true);
+    scrollableTab->setFrameShadow(QFrame::Shadow::Plain);
+    parent->addTab(scrollableTab, title);
+}
 
 
 KCMWacomTabletWidget::KCMWacomTabletWidget( QWidget *parent )
@@ -239,11 +248,13 @@ void KCMWacomTabletWidget::saveProfile()
 {
     Q_D( KCMWacomTabletWidget );
 
+    auto &profileManagement = ProfileManagement::instance();
+
     d->generalPage.saveToProfile();
-    d->stylusPage.saveToProfile();
-    d->buttonPage.saveToProfile();
-    d->tabletPage.saveToProfile();
-    d->touchPage.saveToProfile();
+    d->stylusPage.saveToProfile(profileManagement);
+    d->buttonPage.saveToProfile(profileManagement);
+    d->tabletPage.saveToProfile(profileManagement);
+    d->touchPage.saveToProfile(profileManagement);
 
     d->profileChanged = false;
     emit changed( false );
@@ -267,11 +278,13 @@ void KCMWacomTabletWidget::reloadProfile()
 {
     Q_D( KCMWacomTabletWidget );
 
+    auto &profileManagement = ProfileManagement::instance();
+
     d->generalPage.loadFromProfile();
-    d->stylusPage.loadFromProfile();
-    d->buttonPage.loadFromProfile();
-    d->tabletPage.loadFromProfile();
-    d->touchPage.loadFromProfile();
+    d->stylusPage.loadFromProfile(profileManagement);
+    d->buttonPage.loadFromProfile(profileManagement);
+    d->tabletPage.loadFromProfile(profileManagement);
+    d->touchPage.loadFromProfile(profileManagement);
 
     d->profileChanged = false;
     emit changed( false );
@@ -424,20 +437,20 @@ void KCMWacomTabletWidget::showConfig()
 
     // initialize configuration tabs
     d->ui.deviceTabWidget->clear();
-    d->ui.deviceTabWidget->addTab( &(d->generalPage), i18nc( "Basic overview page for the tablet hardware", "General" ) );
-    d->ui.deviceTabWidget->addTab( &(d->stylusPage), i18n( "Stylus" ) );
+    makeScrollableTab(d->ui.deviceTabWidget, d->generalPage, i18nc( "Basic overview page for the tablet hardware", "General" ) );
+    makeScrollableTab(d->ui.deviceTabWidget, d->stylusPage, i18n( "Stylus" ) );
 
 
     QDBusReply<bool> hasPadButtons = DBusTabletInterface::instance().hasPadButtons(tabletId);
 
     if( hasPadButtons.isValid() && hasPadButtons.value() ) {
-        d->ui.deviceTabWidget->addTab( &(d->buttonPage), i18n( "Express Buttons" ) );
+        makeScrollableTab(d->ui.deviceTabWidget, d->buttonPage, i18n( "Express Buttons" ) );
     }
 
-    d->ui.deviceTabWidget->addTab( &(d->tabletPage), i18n ("Tablet") );
+    makeScrollableTab(d->ui.deviceTabWidget, d->tabletPage, i18n ("Tablet") );
 
     if (hasBuiltInTouch || hasPairedTouch) {
-        d->ui.deviceTabWidget->addTab( &(d->touchPage), i18n ("Touch") );
+        makeScrollableTab(d->ui.deviceTabWidget, d->touchPage, i18n ("Touch") );
     }
 
     d->ui.deviceTabWidget->setEnabled( true );
@@ -456,32 +469,15 @@ void KCMWacomTabletWidget::showSaveChanges()
 {
     Q_D( KCMWacomTabletWidget );
 
-    if( d->profileChanged ) {
-        QPointer<QDialog> saveDialog = new QDialog();
-        QWidget*          widget     = new QWidget( this );
+    if (!d->profileChanged) {
+        return;
+    }
 
-        Ui::SaveProfile askToSave;
-        askToSave.setupUi( widget );
-
-        QVBoxLayout* layout = new QVBoxLayout;
-        QDialogButtonBox* buttonBox = new QDialogButtonBox(QDialogButtonBox::Apply | QDialogButtonBox::Cancel);
-        layout->addWidget( widget );
-        layout->addWidget( buttonBox);
-
-        connect( buttonBox, &QDialogButtonBox::clicked, [saveDialog, buttonBox](QAbstractButton* button) {
-            auto standardButton = buttonBox->standardButton(button);
-            if (standardButton == QDialogButtonBox::Apply) {
-                saveDialog->accept();
-            } else { // Cancel
-                saveDialog->reject();
-            }
-        });
-
-        if( saveDialog->exec() == QDialog::Accepted ) {
-            saveProfile();
-        }
-
-        delete saveDialog;
+    // TODO: This should be a proper Yes/No/Cancel dialog
+    // but this probably requires custom ComboBoxes for canceling selection
+    if (KMessageBox::questionYesNo(this, i18n("Save changes to the current profile?"))
+            == KMessageBox::Yes) {
+        saveProfile();
     }
 }
 
