@@ -43,7 +43,7 @@ class KeySequenceInputButtonPrivate;
  * all key codes of the sequence. While the original implementation would convert
  * "Shift+1" to "!", this implementation will actually return "Shift+!". The wacom
  * driver can not convert shifted keys back to its original key sequence as it
- * treats evey key as a keycode. Therefore we have to make sure we return every
+ * treats every key as a keycode. Therefore we have to make sure we return every
  * key which was pressed.
  */
 class KeySequenceInputButton : public QPushButton
@@ -56,7 +56,7 @@ public:
     KeySequenceInputButton(QWidget *parent = 0);
 
     //! Destructor
-    virtual ~KeySequenceInputButton();
+    ~KeySequenceInputButton() override;
 
     //! Clears the current sequence.
     void clearSequence();
@@ -80,13 +80,13 @@ protected:
     void cancelRecording();
 
     // overloaded from QPushButton
-    virtual bool event (QEvent *event);
+    bool event (QEvent *event) override;
 
     // overloaded from QPushButton
-    virtual void keyPressEvent (QKeyEvent *event);
+    void keyPressEvent (QKeyEvent *event) override;
 
     // overloaded from QPushButton
-    virtual void keyReleaseEvent (QKeyEvent *event);
+    void keyReleaseEvent (QKeyEvent *event) override;
 
     //! Starts shortcut recording.
     void startRecording();
