@@ -46,33 +46,20 @@ public:
     /**
       * default constructor
       *
+      * @param initialValue initial value of the pressure
+      * @param tabletId tablet identifier
+      * @param deviceType device type, @see DeviceType
       * @param parent parent widget
       */
-    explicit PressureCurveDialog(QWidget *parent = 0);
+    PressureCurveDialog(const QString &initialValue,
+                        const QString &tabletId,
+                        const DeviceType& deviceType,
+                        QWidget *parent = 0);
 
     /**
       * default destructor
       */
-    ~PressureCurveDialog();
-
-    /**
-      * Sets the controllpoints to some starting values
-      *
-      * @param points starting values in the format as expected by the xssetwacom settings
-      */
-    void setControllPoints(const QString & points);
-
-    void setTabletId(const QString &tabletId);
-
-    /**
-      * Sets the currently used WacomInterface instance to allow on the fly changing of the presscurve
-      * Gives a better feeling when changing the beziercurve and directly see how this affects
-      * the applied pressure with the pen
-      *
-      * @param deviceInterface Interface for the connection to the tablet device.
-      * @param device devicename as used by the xsetwacomsetting for the stylus/eraser and named in the xorg.conf or by HAL
-      */
-    void setDeviceType (const DeviceType& deviceType);
+    ~PressureCurveDialog() override;
 
     /**
       * Returns the changed presscurve control points in the format needed by the xsetwacom settings
@@ -83,7 +70,7 @@ public:
 
 public slots:
     /**
-      * Updates the pen presscurve viathe xsetwacom settings and shows the values in the dialog
+      * Updates the pen presscurve via the xsetwacom settings and shows the values in the dialog
       *
       * @param points string version of both control points separated by spaces
       */
@@ -92,18 +79,28 @@ public slots:
     /**
       * called when the user accept his changes
       */
-    void accept();
+    void accept() override;
 
     /**
       * called when the user discards his changes
       */
-    void reject();
+    void reject() override;
 
 private:
-    Ui::PressureCurveDialog *m_ui;                   /**< Handler to the presscurvedialog.ui file */
-    QString                  m_device;
-    PressureCurveWidget     *m_pressCurve = nullptr; /**< Widget that shows the presscurve and lets him change it */
-    QString                  m_tabletId;
+    /**
+      * Sets the controllpoints to some starting values
+      *
+      * @param points starting values in the format as expected by the xssetwacom settings
+      */
+    void setControllPoints(const QString & points);
+
+private:
+    Ui::PressureCurveDialog *m_ui = nullptr;                   /**< Handler to the presscurvedialog.ui file */
+    PressureCurveWidget *m_pressCurve = nullptr; /**< Widget that shows the presscurve and lets him change it */
+
+    QString _initialValue;
+    QString _tabletId;
+    QString _deviceType;
 };
 }
 #endif // PRESSURECURVEDIALOG_H
