@@ -60,7 +60,7 @@ public:
       * @bug if this widget has no fixed size, the width()/height() return the
       *      the values as specified in the .ui file or when the widget is created
       *      The automatic layout changes took place before somehow and thus
-      *      leeds to a wrong placement of the control points
+      *      leads to a wrong placement of the control points
       * @param p1 x value of the first point
       * @param p2 y value of the first point
       * @param p3 x value of the second point
@@ -75,7 +75,7 @@ protected:
       *
       * @param event the mouse event
       */
-    void mousePressEvent(QMouseEvent * event);
+    void mousePressEvent(QMouseEvent * event) override;
 
     /**
       * Drags the control points around
@@ -84,7 +84,7 @@ protected:
       *
       * @param event the mouse event
       */
-    void mouseMoveEvent(QMouseEvent * event);
+    void mouseMoveEvent(QMouseEvent * event) override;
 
     /**
       * Dragging the controlpoint stopped
@@ -92,7 +92,7 @@ protected:
       *
       * @param event the mouse event
       */
-    void mouseReleaseEvent(QMouseEvent * event);
+    void mouseReleaseEvent(QMouseEvent * event) override;
 
     /**
       * Changes the position of the controlpoints with the same ratio than the widget resize
@@ -100,7 +100,7 @@ protected:
       *
       * @param event the resize event
       */
-    void resizeEvent(QResizeEvent * event);
+    void resizeEvent(QResizeEvent * event) override;
 
     /**
       * If the tablet was detected by Qt this animates the pressure as filled area below the presscurve
@@ -109,7 +109,7 @@ protected:
       *
       * @param event the Tablet event
       */
-    void tabletEvent(QTabletEvent * event);
+    void tabletEvent(QTabletEvent * event) override;
 
     /**
       * Draws the background grid, controlpoints and the presscurve on the widget
@@ -117,7 +117,7 @@ protected:
       *
       * @param event the paint event
       */
-    void paintEvent(QPaintEvent *event);
+    void paintEvent(QPaintEvent *event) override;
 
     /**
       * Finds the nearest controlpoint the uses clicks on
@@ -142,7 +142,7 @@ signals:
     /**
       * This signal will be fired if the position of the control points change
       * Used to inform the parent widget of this change to be able to display the new values
-      * Furthermore the changed presscurve will be set via the xsetwacom driver imidiatly thus
+      * Furthermore the changed presscurve will be set via the xsetwacom driver immediatly thus
       * allow the user to see the changes in action right now
       *
       * @param points the presscurve points in a format expected by the xsetwacom driver (like "0 100 0 100")
@@ -156,7 +156,7 @@ private:
     int     m_activePoint = 0;            /**< The point that is dragged around */
     QColor  m_pointColor = Qt::red;       /**< Color of the points */
     QColor  m_curveColor = Qt::black;     /**< Color of the curve */
-    qreal   m_presssure = 0;              /**< Buffers the current stylus pressure. (0.0 - 1.0) used to animate the pressure */
+    qreal   m_pressure = 0;              /**< Buffers the current stylus pressure. (0.0 - 1.0) used to animate the pressure */
     QColor  m_pressAreaColor = Qt::blue;  /**< Color of the press indication area */
 };
 
