@@ -22,14 +22,20 @@
 
 #include <QWidget>
 
+namespace Ui {
+    class StylusPageWidget;
+}
+
 namespace Wacom
 {
 
 class StylusPageWidgetPrivate;
 
 class ButtonShortcut;
+class DeviceProfile;
 class DeviceType;
 class Property;
+class ProfileManagementInterface;
 
 /**
  * @brief Provides interface to all settings for the stylus/eraser pen.
@@ -41,7 +47,7 @@ class StylusPageWidget : public QWidget
 public:
     explicit StylusPageWidget(QWidget *parent = 0);
 
-    ~StylusPageWidget();
+    ~StylusPageWidget() override;
 
     void setTabletId(const QString &tabletId);
 
@@ -50,7 +56,7 @@ public:
       *
       * Updates all values on the widget to the values from the profile.
       */
-    void loadFromProfile();
+    void loadFromProfile(ProfileManagementInterface &profileManagement);
 
     /**
       * Reloads the widget when the status of the tablet device changes (connects/disconnects)
@@ -60,7 +66,7 @@ public:
     /**
       * Saves all values to the current profile
       */
-    void saveToProfile();
+    void saveToProfile(ProfileManagementInterface &profileManagement);
 
 
 public slots:
@@ -112,17 +118,18 @@ protected:
 
 
 private:
+    void savePropertiesToDeviceProfile(DeviceProfile &profile) const;
 
-    void changePressureCurve (const DeviceType& deviceType);
+    void openPressureCurveDialog (const DeviceType& deviceType);
 
     /**
      * Sets up the user interface widgets. Should only be called once by a constructor.
      */
     void setupUi();
 
-    Q_DECLARE_PRIVATE( StylusPageWidget )
-    StylusPageWidgetPrivate *const d_ptr; /**< d-pointer for this class */
-
+private:
+    QString _tabletId;
+    Ui::StylusPageWidget *ui = nullptr;
 }; // CLASS
 }  // NAMESPACE
 #endif /*STYLUSPAGEWIDGET_H*/
