@@ -41,7 +41,7 @@ class TabletAreaSelectionController : public QObject
 public:
 
     TabletAreaSelectionController();
-    virtual ~TabletAreaSelectionController();
+    ~TabletAreaSelectionController() override;
 
 
     /**
@@ -78,7 +78,6 @@ public:
      * @param mappings The screen mappings of the device we are handling.
      * @param deviceName The X11 xinput device name of the device we ware handling.
      * @param rotation The currently selected tablet rotation.
-     * @param isTouchDevice A flag if the device we are handling is a touch device.
      */
     void setupController(const ScreenMap& mappings, const QString& deviceName, const ScreenRotation& rotation);
 
