@@ -17,12 +17,11 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "debug.h" // always needs to be first include
-
 #include "tabletareaselectionview.h"
+
 #include "ui_tabletareaselectionview.h"
 
-#include <QList>
+#include <logging.h>
 
 using namespace Wacom;
 
@@ -36,7 +35,7 @@ namespace Wacom
                 delete ui;
             }
 
-            Ui::TabletAreaSelectionView* ui;
+            Ui::TabletAreaSelectionView *ui = nullptr;
     }; // PRIVATE CLASS
 } // NAMESPACE
 
@@ -60,14 +59,6 @@ const TabletArea TabletAreaSelectionView::getSelection() const
     return TabletArea(d->ui->areaWidget->getSelection());
 }
 
-
-bool TabletAreaSelectionView::isAreaSelectionMode() const
-{
-    Q_D(const TabletAreaSelectionView);
-
-    return d->ui->tabletAreaRadioButton->isChecked();
-}
-
 void TabletAreaSelectionView::selectFullTablet()
 {
     Q_D(TabletAreaSelectionView);
@@ -82,7 +73,7 @@ void TabletAreaSelectionView::selectPartOfTablet(const TabletArea &selection)
     Q_D(TabletAreaSelectionView);
 
     setTabletAreaType(TabletAreaSelectionView::PartialTabletArea);
-    d->ui->areaWidget->setSelection(selection);
+    d->ui->areaWidget->setSelection(selection, true);
 }
 
 
@@ -147,7 +138,7 @@ void TabletAreaSelectionView::setupScreens(const QMap<QString, QRect> &screenGeo
         d->ui->screenArea->setDrawSelectionCaption(false);
         d->ui->screenArea->setArea(QRect(0,0,1920,1200), i18n("Internal Error"));
         // We call this intentionally with no screens from setupUI()
-        dbgWacom << "Call to TabletAreaSelectionView::setupScreens made with no valid screens.";
+        qCWarning(KCM) << "Call to TabletAreaSelectionView::setupScreens made with no valid screens.";
     }
 
     // defaults to full selection
@@ -175,7 +166,7 @@ void TabletAreaSelectionView::setupTablet(const TabletArea &geometry, const QSiz
         d->ui->areaWidget->setDrawAreaCaptions(true);
         d->ui->areaWidget->setDrawSelectionCaption(false);
         d->ui->areaWidget->setArea(QRect(0,0,1920,1200), i18n("Internal Error"));
-        errWacom << "Internal error, invalid tablet geometry -" << geometry.toString();
+        qCWarning(KCM) << "Internal error, invalid tablet geometry -" << geometry.toString();
     }
 
     // defaults to full selection
@@ -220,6 +211,13 @@ void TabletAreaSelectionView::onTabletAreaSelected(bool checked)
     setTabletAreaType(TabletAreaSelectionView::PartialTabletArea);
 }
 
+void TabletAreaSelectionView::onLockProportionsToggled(bool enabled)
+{
+    Q_D(TabletAreaSelectionView);
+
+    d->ui->areaWidget->lockProportions(enabled);
+}
+
 
 void TabletAreaSelectionView::setSelection(const TabletArea &selection)
 {
@@ -264,7 +262,39 @@ void TabletAreaSelectionView::setTabletAreaType(TabletAreaSelectionView::TabletA
     d->ui->tabletAreaRadioButton->blockSignals(false);
 }
 
+void TabletAreaSelectionView::onSelectionChanged()
+{
+    Q_D(TabletAreaSelectionView);
 
+    const auto selection = d->ui->areaWidget->getSelection();
+
+    d->ui->lineEditX->setText(QString::number(selection.x()));
+    d->ui->lineEditY->setText(QString::number(selection.y()));
+    d->ui->lineEditWidth->setText(QString::number(selection.width()));
+    d->ui->lineEditHeight->setText(QString::number(selection.height()));
+}
+
+void TabletAreaSelectionView::onFineTuneValuesChanged(QString)
+{
+    Q_D(TabletAreaSelectionView);
+
+    bool xvalid = true;
+    bool yvalid = true;
+    bool wvalid = true;
+    bool hvalid = true;
+
+    const QRect newSelection(d->ui->lineEditX->text().toInt(&xvalid),
+                             d->ui->lineEditY->text().toInt(&yvalid),
+                             d->ui->lineEditWidth->text().toInt(&wvalid),
+                             d->ui->lineEditHeight->text().toInt(&hvalid));
+
+    if (newSelection.isEmpty() || !newSelection.isValid()
+            || !xvalid || !yvalid || !wvalid || !hvalid) {
+        return;
+    }
+
+    d->ui->areaWidget->setSelection(newSelection, false);
+}
 
 bool TabletAreaSelectionView::isFullAreaSelection(const TabletArea &selection) const
 {
@@ -285,9 +315,16 @@ void TabletAreaSelectionView::setupUi()
     d->ui->warningIcon->setVisible(true);
     d->ui->warningLabel->setVisible(false);
 
+    // FIXME: signal-slot editor can't see this signal for some reason
+    // TODO: rename areaWidget and screenArea, this is confusing
+    connect(d->ui->areaWidget, &AreaSelectionWidget::selectionChanged, this, &TabletAreaSelectionView::onSelectionChanged);
+
+    connect(d->ui->lineEditX, &QLineEdit::textChanged, this, &TabletAreaSelectionView::onFineTuneValuesChanged);
+    connect(d->ui->lineEditY, &QLineEdit::textChanged, this, &TabletAreaSelectionView::onFineTuneValuesChanged);
+    connect(d->ui->lineEditHeight, &QLineEdit::textChanged, this, &TabletAreaSelectionView::onFineTuneValuesChanged);
+    connect(d->ui->lineEditWidth, &QLineEdit::textChanged, this, &TabletAreaSelectionView::onFineTuneValuesChanged);
+
     // Is this next call, like, fake?
     setupScreens(QMap<QString, QRect>(), QSize(200,200));
     setupTablet(TabletArea(), QSize(400,400));
 }
-
-
