@@ -27,10 +27,14 @@
 #include <QWidget>
 #include <QString>
 
+namespace Ui {
+    class TabletPageWidget;
+}
+
 namespace Wacom
 {
 
-class TabletPageWidgetPrivate;
+class ProfileManagementInterface;
 
 /**
  * The "Tablet" tab of the main KCM widget.
@@ -43,14 +47,14 @@ public:
 
     explicit TabletPageWidget( QWidget *parent = 0 );
 
-    virtual ~TabletPageWidget();
+    ~TabletPageWidget() override;
 
     void setTabletId(const QString &tabletId);
 
     /**
      * Loads settings from the current profile and updates the widget accordingly.
      */
-    void loadFromProfile();
+    void loadFromProfile(ProfileManagementInterface &profileManagement);
 
     /**
      * Reinitializes the widget when a new tablet gets connected.
@@ -60,7 +64,7 @@ public:
     /**
      * Saves the current settings to the current profile.
      */
-    void saveToProfile();
+    void saveToProfile(ProfileManagementInterface &profileManagement);
 
 
 public slots:
@@ -172,7 +176,7 @@ protected:
     void setAutoRotationEnabled (bool value);
 
     /**
-     * Changes the inverte-auto rotation configuration. This will not
+     * Changes the inverted-auto rotation configuration. This will not
      * update the auto-rotation flag.
      *
      * @param value True to enable inverted auto-rotation, false to disable it.
@@ -206,7 +210,7 @@ protected:
     /**
      * Sets a new screen area mapping and updates all widgets accordingly.
      *
-     * @param value The new screen space mapping selection.
+     * @param screenSpace The new screen space mapping selection.
      */
     void setScreenSpace(const ScreenSpace& screenSpace);
 
@@ -239,8 +243,15 @@ private:
      */
     void setupUi();
 
-    Q_DECLARE_PRIVATE( TabletPageWidget )
-    TabletPageWidgetPrivate *const d_ptr; //!< D-Pointer for this class.
+private:
+    Ui::TabletPageWidget *ui;
+    QString _tabletId;
+    TabletArea            _tabletGeometry;    // The full tablet area as rectangle.
+    ScreenMap             _screenMap;         // The current tablet to screen mapping of the pad.
+    ScreenSpace           _screenSpace;       // The current screen mapping of the pad.
+
+    QString               _deviceNameStylus;  // The Xinput name of the stylus device of the current tablet.
+    QString               _deviceNameTouch;   // The Xinput name of the touch device of the current tablet.
 
 }; // CLASS
 }  // NAMESPACE
