@@ -46,13 +46,13 @@ class DBusTabletService : public QObject
 
 public:
      explicit DBusTabletService (TabletHandlerInterface& tabletHandler);
-    ~DBusTabletService ();
+    ~DBusTabletService () override;
 
 
 // d-bus slots
 public Q_SLOTS:
     /**
-      * List all conncted tablets (by tabletid)
+      * List all connected tablets (by tabletid)
       *
       * @return StringList of the connected tablets with their id
       */
