@@ -21,7 +21,7 @@
 
 using namespace Wacom;
 
-// instances container specialization instanciation
+// instances container specialization instantiation
 template<>
 ProcSystemPropertyTemplateSpecialization::PropertySetTemplateSpecialization::Container ProcSystemPropertyTemplateSpecialization::PropertySetTemplateSpecialization::instances = ProcSystemPropertyTemplateSpecialization::PropertySetTemplateSpecialization::Container();
 
@@ -29,4 +29,4 @@ ProcSystemPropertyTemplateSpecialization::PropertySetTemplateSpecialization::Con
 // SOME PROPERTIES NEED TO BE SET BEFORE OTHERS!
 //
 const ProcSystemProperty ProcSystemProperty::StatusLEDs              ( Property::StatusLEDs,              QLatin1String("Status LEDs for Intuos4/5 and Cintiq") );
-const ProcSystemProperty ProcSystemProperty::StatusLEDsBrightness              ( Property::StatusLEDsBrightness,              QLatin1String("Status LED Brighness for Intuos4/5 and Cintiq") );
+const ProcSystemProperty ProcSystemProperty::StatusLEDsBrightness              ( Property::StatusLEDsBrightness,              QLatin1String("Status LED Brightness for Intuos4/5 and Cintiq") );
