@@ -35,7 +35,7 @@
 #include "profilemanager.h"
 #include "profilemanagement.h"
 #include "tabletprofile.h"
-#include "x11info.h"
+#include "screensinfo.h"
 
 #include <QGuiApplication>
 #include <QList>
@@ -139,10 +139,10 @@ void TabletHandler::onTabletAdded( const TabletInformation& info )
     d->tabletInformationList.insert(tabletId, info);
 
     // if we found something notify about it and set the default profile to it
-    emit notify( QLatin1String("tabletAdded"),
-                 i18n("Tablet Connected"),
-                 i18n("New tablet '%1' connected.",
-                 info.get(TabletInfo::TabletName) ));
+    emit notify(QLatin1String("tabletAdded"),
+                i18n("Tablet Connected"),
+                i18n("New tablet '%1' connected.", info.get(TabletInfo::TabletName)),
+                true);
 
     // set profile which was last used
     auto lastProfile = d->mainConfig.getLastProfile(info.getUniqueDeviceId());
@@ -170,10 +170,10 @@ void TabletHandler::onTabletRemoved( const TabletInformation& info )
     TabletInformation       ti  = d->tabletInformationList.value(info.get(TabletInfo::TabletId));
 
     if ( tbi && ti.getTabletSerial() == info.getTabletSerial() ) {
-        emit notify( QLatin1String("tabletRemoved"),
-                     i18n("Tablet removed"),
-                     i18n("Tablet %1 removed",
-                     ti.get(TabletInfo::TabletName) ));
+        emit notify(QLatin1String("tabletRemoved"),
+                    i18n("Tablet removed"),
+                    i18n("Tablet %1 removed", ti.get(TabletInfo::TabletName)),
+                    false);
 
         QString tabletId = info.get(TabletInfo::TabletId);
         d->tabletBackendList.remove(tabletId);
@@ -359,7 +359,7 @@ void TabletHandler::onMapToScreen1()
     Q_D( TabletHandler );
 
     foreach(const QString &tabletId, d->tabletInformationList.keys()) {
-        mapPenToScreenSpace(tabletId, ScreenSpace::monitor(X11Info::getPrimaryScreenName()));
+        mapPenToScreenSpace(tabletId, ScreenSpace::monitor(ScreensInfo::getPrimaryScreenName()));
     }
 }
 
@@ -371,7 +371,7 @@ void TabletHandler::onMapToScreen2()
 
     if (QGuiApplication::screens().count() > 1) {
         foreach(const QString &tabletId, d->tabletInformationList.keys()) {
-            mapPenToScreenSpace(tabletId, ScreenSpace::monitor(X11Info::getPrimaryScreenName()).next());
+            mapPenToScreenSpace(tabletId, ScreenSpace::monitor(ScreensInfo::getPrimaryScreenName()).next());
         }
     }
 }
@@ -470,9 +470,10 @@ void TabletHandler::setProfile( const QString &tabletId, const QString &profile
         }
         else {
             qCWarning(KDED) << QString::fromLatin1("Tablet profile '%1' does not exist!").arg(profile);
-            emit notify( QLatin1String( "tabletError" ),
-                         i18n( "Graphic Tablet error" ),
-                         i18n( "Profile <b>%1</b> does not exist. Apply <b>%2</b> instead", profile, pList.first() ) );
+            emit notify(QLatin1String( "tabletError"),
+                        i18n( "Graphic Tablet error" ),
+                        i18n( "Profile <b>%1</b> does not exist. Apply <b>%2</b> instead", profile, pList.first() ),
+                        true);
 
             // set first known profile instead
             d->currentProfileList.insert(tabletId, pList.first());
@@ -580,7 +581,7 @@ void TabletHandler::autoRotateTablet(const QString &tabletId,
     }
 
     if (output.isEmpty()) {
-        screenRotation = X11Info::getScreenRotation(stylusSpace.toString());
+        screenRotation = ScreensInfo::getScreenRotation(stylusSpace.toString());
     } else if (output != stylusSpace.toString() && QGuiApplication::screens().count() > 1) {
         qCDebug(KDED) << "Tablet is mapped to a different screen";
         return;
@@ -632,10 +633,10 @@ void TabletHandler::mapDeviceToOutput(const QString &tabletId,
     ScreenSpace screen(screenSpace);
 
     if (screen.isMonitor() &&
-            (!X11Info::getScreenGeometries().contains(screen.toString())
+            (!ScreensInfo::getScreenGeometries().contains(screen.toString())
              || QGuiApplication::screens().count() == 1)) {
         /**
-         * If we we have only one screen, or if the screen number is invalid,
+         * If we have only one screen, or if the screen number is invalid,
          * map to whole desktop.
          */
         screen = ScreenSpace::desktop();
