@@ -24,14 +24,7 @@
 #include "deviceinformation.h"
 #include "x11input.h"
 
-#if defined(HAVE_XCB_XINPUT)
-# include <xcb/xcb.h>
-#else
-# include <X11/Xlib.h>
-# include <X11/Xatom.h>
-# include <X11/extensions/XInput.h>
-# include <X11/Xutil.h>
-#endif
+#include <xcb/xcb.h>
 
 #include <QString>
 #include <QMap>
@@ -269,25 +262,12 @@ const QString X11TabletFinder::getToolType (X11InputDevice& device) const
     QString toolTypeName;
 
     if (toolTypeAtoms.size() == 1) {
-
-#if defined(HAVE_XCB_XINPUT)
         xcb_get_atom_name_cookie_t cookie = xcb_get_atom_name(QX11Info::connection(), toolTypeAtoms.at(0));
         xcb_get_atom_name_reply_t* reply = xcb_get_atom_name_reply(QX11Info::connection(), cookie, nullptr);
         if (reply) {
             toolTypeName = QString::fromLatin1(QByteArray(xcb_get_atom_name_name(reply), xcb_get_atom_name_name_length(reply)));
             free(reply);
         }
-
-#else  // HAVE_XCB_XINPUT
-        char *type_name = XGetAtomName (device.getDisplay(), (Atom)toolTypeAtoms.at(0));
-        if (type_name != nullptr) {
-            toolTypeName = QLatin1String(type_name);
-            XFree( type_name );
-        } else {
-            qCDebug(KDED) << "Could not get tool type of device" << device.getName();
-        }
-
-#endif // HAVE_XCB_XINPUT
     }
 
     return toolTypeName;
