@@ -46,12 +46,12 @@ class HWButtonDialog : public QDialog
 
 public:
     explicit HWButtonDialog(int maxButtons, QWidget *parent = nullptr);
-    ~HWButtonDialog();
+    ~HWButtonDialog() override;
 
     QList<unsigned int> buttonMap() const;
 
 protected:
-    void mousePressEvent(QMouseEvent *event) final;
+    void mousePressEvent(QMouseEvent *event) final override;
 
 private:
     void hwKey(unsigned int button);
