@@ -18,10 +18,14 @@
  */
 
 #include "dialog.h"
+
+#include <KLocalizedString>
+
 #include <QApplication>
 
 int main(int argc, char *argv[])
 {
+    KLocalizedString::setApplicationDomain("wacomtablet");
     QApplication a(argc, argv);
     Wacom::Dialog w;
     w.show();
